@@ -4,6 +4,7 @@ set -ex
 
 
 
-clang-format --version
+clang-format-13 --version
+test ! -f ${PREFIX}/bin/clang-format
 test ! -f ${PREFIX}/bin/c-index-test
 exit 0
